@@ -72,8 +72,6 @@ extern	char	*Curr_pwd;
 
 jobno_t	Cjobno = -1;
 
-extern	BtuserRef	mypriv;
-
 #define	ppermitted(flg)	(mypriv->btu_priv & flg)
 
 int	Jhline,
@@ -84,9 +82,6 @@ static	char	*more_amsg,
 		*defcondstr,
 		*localrun;
 
-char		*exitcodename,
-		*signalname;
-
 char	*exportmark, *clustermark;	/* Actually these are for variables */
 
 static	int	more_above,
@@ -97,10 +92,6 @@ static	HelpaltRef	progresslist,
 			sproglist,
 			killlist;
 
-HelpaltRef		repunit,
-			ifnposses,
-			days_abbrev;
-
 extern const char * const condname[];
 extern const char * const assname[];
 
