@@ -57,30 +57,7 @@
 
 static	char	Filename[] = __FILE__;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-FILE	*Cfile;
-
-char	*Restru, *Restrg, *jobqueue;		/* Resolution only */
-
-#ifdef	SHAREDLIBS
-#include "timecon.h"
-#include "btjob.h"
-#include "q_shm.h"
-int		Ctrl_chan;
-long		mymtype;
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*Args[1], *exitcodename, *signalname;
-BtuserRef	mypriv;
-struct	jshm_info	Job_seg;
 extern	netid_t	Out_host;
-#else
-netid_t	Out_host;
-#endif
 
 /* For when we run out of memory.....  */
 
