@@ -38,6 +38,7 @@
 #include "incl_unix.h"
 #include "incl_sig.h"
 #include "defaults.h"
+#include "incl_ugid.h"
 #include "files.h"
 #include "ecodes.h"
 #include "helpargs.h"
@@ -185,39 +186,9 @@ DIR		*Dir_p;
 unsigned	long		scan_seq;	/* Number of scans we've done */
 time_t		last_mtime;			/* Of directory we're looking at */
 
-uid_t	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-FILE	*Cfile;
 char	Confvarname[] = "FILEMONCONF";
 
-char	*Restru,
-	*Restrg,
-	*jobqueue;				/* Resolution only */
-
-#ifdef	SHAREDLIBS
-#include "bjparam.h"
-#include "cmdint.h"
-#include "btconst.h"
-#include "btmode.h"
-#include "btvar.h"
-#include "btuser.h"
-#include "timecon.h"
-#include "btjob.h"
-#include "q_shm.h"
-
-int		Ctrl_chan;
-long		mymtype;
-uid_t		Daemuid;
 ULONG		Fileprivs;
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*Args[1], *exitcodename, *signalname;
-BtuserRef	mypriv;
-struct		jshm_info	Job_seg;
-#endif
-
 int	sem_chan, shm_chan;
 struct	fm_shm_entry	*shm_list,
 			*my_shm_slot;
