@@ -41,26 +41,7 @@
 #include "errnums.h"
 #include "ipcstuff.h"
 
-FILE	*Cfile;
-int	Ctrl_chan;
-
-uid_t	Realuid,
-	Effuid,
-	Daemuid;
-gid_t	Realgid,
-	Effgid;
-
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-#include "q_shm.h"
-#include "btuser.h"
-long		mymtype;
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*Args[1], *exitcodename, *signalname;
-char		*Restru, *Restrg, *jobqueue;
-BtuserRef	mypriv;
-struct	jshm_info	Job_seg;
-#endif
+extern	int	Ctrl_chan;
 
 void  nomem(const char *fl, const int ln)
 {
@@ -80,7 +61,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	Shipc	oreq;
 	Repmess	rep;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
