@@ -120,21 +120,13 @@ struct	vshm_info	Var_seg;
 
 int	qchanges;
 
-uid_t	Daemuid,
-	Daemgid;
-
-#ifdef	SHAREDLIBS
-uid_t	Realuid;
-gid_t	Realgid;
-#endif
-
 unsigned	Startlim,
 		Startwait;
 
 LONG	Max_ll,
 	Current_ll;
 
-FILE	*Cfile;
+FILE	*Cfile;			/* Need this here because std one in client library */
 
 char	*spdir;
 
@@ -1430,10 +1422,9 @@ MAINFN_TYPE  main(int argc, char **argv)
 		exit(E_NOCHDIR);
 	}
 
-#ifdef	SHAREDLIBS
 	Realuid = getuid();
 	Realgid = getgid();
-#endif
+
 #ifdef	HAVE_GETGROUPS
 	Requires_suppgrps = 1;
 	setgroups(0, &dumm); /* Zap any existing supp groups */
