@@ -51,30 +51,12 @@
 #include "helpargs.h"
 #include "cfile.h"
 #include "optflags.h"
-
-FILE	*Cfile;
-int	Ctrl_chan;
-
-uid_t	Realuid, Effuid, Daemuid;
-gid_t	Realgid, Effgid;
+#include "shutilmsg.h"
 
 int	nosetpgrp = 0;
 LONG	initll = -1, jsize = 0L, vsize = 0L;
 float	decpri = 0.0;
 
-char	*Restru, *Restrg, *jobqueue;
-
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-#include "q_shm.h"
-
-long		mymtype;
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*Args[1], *exitcodename, *signalname;
-BtuserRef	mypriv;
-struct	jshm_info	Job_seg;
-#endif
-
 /* For when we run out of memory.....  */
 
 void  nomem(const char *fl, const int ln)
@@ -88,7 +70,6 @@ static int  doconnop(const unsigned cmd, const char *hostn)
 {
 	struct	remote	*rp;
 	long		mymtype;
-	BtuserRef	mypriv;
 	Shipc		oreq;
 	Repmess		rr;
 
