@@ -47,44 +47,17 @@
 #include "jvuprocs.h"
 #include "formats.h"
 #include "optflags.h"
+#include "shutilmsg.h"
 
 static	char	Filename[] = __FILE__;
 
 char	bypassflag;
 
-char	*Restru,
-	*Restrg,
-	*jobqueue;
-
 char	*formatstring;
 char	defaultformat[] = "%N %V %E # %C";
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-gid_t	Realgid,
-	Effgid;
-
-BtuserRef	mypriv;
-
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-long	mymtype;
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*Args[1], *exitcodename, *signalname;
-struct	jshm_info	Job_seg;
-#endif
-
-FILE	*Cfile;
-
 #define	IPC_MODE	0600
 
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-
 struct	varswanted	{
 	netid_t		host;
 	char		varname[BTV_NAME+1];
