@@ -28,6 +28,7 @@
 #endif
 #include "incl_unix.h"
 #include "defaults.h"
+#include "incl_ugid.h"
 #include "errnums.h"
 #include "ecodes.h"
 #include "files.h"
@@ -43,7 +44,7 @@ extern char *strread(FILE *, const char *);
 
 #define	INCFILES	10
 
-FILE	*Cfile;
+FILE	*Cfile;					/* Need to define this here as not using client lib */
 char	*dispatch;
 
 struct	ostr	{
@@ -54,7 +55,7 @@ struct	ostr	{
 int	fcnt, initfiles;
 int	utmp = -1;
 
-#ifdef	SHAREDLIBS
+/* Satisfy sharedlibs dependencies */
 #include "btmode.h"
 #include "bjparam.h"
 #include "cmdint.h"
@@ -63,11 +64,8 @@ int	utmp = -1;
 #include "timecon.h"
 #include "btjob.h"
 #include "q_shm.h"
-uid_t	Realuid;
-gid_t	Realgid;
-ULONG	Fileprivs;
 struct	jshm_info	Job_seg;
-#endif
+/* End of shared libs dependencies */
 
 static	char	Filename[] = __FILE__;
 
@@ -181,7 +179,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	int	i;
 	char	**hv, *inb;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 1);
+	versionprint(argv, "$Revision: 1.1 $", 1);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
@@ -190,10 +188,8 @@ MAINFN_TYPE  main(int argc, char **argv)
 
 	init_mcfile();
 
-#ifdef	SHAREDLIBS
 	Realuid = getuid();
 	Realgid = getgid();
-#endif
 
 	if  ((Cfile = open_icfile()) == (FILE *) 0)
 		exit(E_NOCONFIG);
