@@ -205,16 +205,13 @@ struct	fielddef	jobflds = { NULL, jlist_els, NUM_JOB_ELS },
 
 extern	Shipc	Oreq;
 
-extern	BtuserRef	mypriv;
-
 #define	ppermitted(flg)	(mypriv->btu_priv & flg)
 
 static	char	*localrun;
 
 static	HelpaltRef	progresslist;
 char			*rdeletemsg, *rretainmsg;
-HelpaltRef		repunit, ifnposses, days_abbrev, varexport_types;
-char			*exitcodename, *signalname;
+HelpaltRef		varexport_types;
 
 extern const char * const condname[];
 extern const char * const assname[];
