@@ -16,7 +16,7 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "config.h"
-static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
+static	char	rcsid2[] = "@(#) $Revision: 1.1 $";
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -74,36 +74,12 @@ void  job_redisplay();
 void  var_redisplay();
 
 char	*spdir,
-	*Curr_pwd,
-	*jobqueue;
-
-#ifdef	SHAREDLIBS
-char	*Args[1];
-#else
-ULONG	Dispflags;
-#endif
-
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-gid_t	Realgid,
-	Effgid;
-
-FILE	*Cfile;
-
-int	Ctrl_chan = -1;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
+	*Curr_pwd;
 
 int	poll_time;
 
 Shipc		Oreq;
-long		mymtype;
-BtuserRef	mypriv;
-
-char	*Restru, *Restrg;
+extern	long	mymtype;
 
 /* X Stuff */
 
@@ -422,7 +398,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 {
 	GtkWidget  *vbox;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
