@@ -16,7 +16,7 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "config.h"
-static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
+static	char	rcsid2[] = "@(#) $Revision: 1.1 $";
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -70,26 +70,9 @@ static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
 void  initcifile();
 
 char	*spdir,
-	*Curr_pwd,
-	*jobqueue;
+	*Curr_pwd;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-FILE	*Cfile;
-
-int	Ctrl_chan = -1;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-
-long	mymtype;
-
-BtuserRef	mypriv;
-char	*Restru, *Restrg;
+extern	long	mymtype;
 
 struct	pend_job	default_pend;
 Btjob			default_job;
@@ -407,7 +390,7 @@ static void  wstart()
 
 MAINFN_TYPE  main(int argc, char **argv)
 {
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
