@@ -16,7 +16,7 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "config.h"
-static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
+static	char	rcsid2[] = "@(#) $Revision: 1.1 $";
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -47,33 +47,8 @@ static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
 #include "xbtu_ext.h"
 #include "gtk_lib.h"
 
-FILE	*Cfile;
-
 char	*Curr_pwd;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-gid_t	Realgid,
-	Effgid;
-
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-#include "timecon.h"
-#include "btconst.h"
-#include "bjparam.h"
-#include "btjob.h"
-#include "q_shm.h"
-int	Ctrl_chan;
-long	mymtype;
-HelpaltRef	repunit, days_abbrev;
-char	*Args[1], *exitcodename, *signalname;
-BtuserRef	mypriv;
-char	*Restru, *Restrg, *jobqueue;
-struct	jshm_info	Job_seg;
-#endif
-
 int	hchanges,	/* Had changes to default */
 	uchanges;	/* Had changes to user(s) */
 
@@ -484,10 +459,9 @@ void  defdisplay()
 
 MAINFN_TYPE  main(int argc, char **argv)
 {
-	BtuserRef	mypriv;
 	GtkWidget  *vbox;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
