@@ -62,7 +62,7 @@ typedef	struct	{
 	double		btu_charge;	/* User's bill */
 }  Btuser_r4;
 
-FILE	*Cfile;
+extern	FILE	*Cfile;
 
 struct  {
 	char	*srcdir;	/* Directory we read from if not pwd */
@@ -295,7 +295,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	extern	int	optind;
 	extern	char	*optarg;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	while  ((ch = getopt(argc, argv, "sfe:v:D:")) != EOF)
 		switch  (ch)  {
