@@ -64,40 +64,22 @@
 #define	IPC_MODE	0
 
 int	nodelete;
-char	*exitcodename,
-	*signalname;
-FILE	*Cfile;
 
 int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-
-#ifdef	SHAREDLIBS
-char	*Args[1];
-BtuserRef	mypriv;
-#endif
 
 BtjobRef		Wj;
-
 jobno_t		Jobnum;
 netid_t		netid;
 char		*Dirname;
 char		*Xfile, *Jfile;
 
 Shipc		Oreq;
-long		mymtype;
-uid_t		Realuid, Effuid, Daemuid;
-gid_t		Realgid, Effgid;
-
-HelpaltRef	repunit, ifnposses, days_abbrev;
-
-char		*Restru, *Restrg, *jobqueue, *job_title; /* Name resolution */
+extern		long  mymtype;
 
 static	enum	{ PD_DUMPJOB, ASCANC, ASRUNN } pardump = PD_DUMPJOB;
 static	enum	{ NOVERBOSE, VERBOSE } Verbose = NOVERBOSE;
 
-FILE *net_feed(const int, const netid_t, const jobno_t);
+FILE *net_feed(const int, const netid_t, const jobno_t, const int);
 
 /* For when we run out of memory.....  */
 
@@ -158,7 +140,7 @@ void  dumpjob(BtjobRef jp)
 	int	ch;
 
 	if  (netid)
-		ifl = net_feed(FEED_JOB, netid, Jobnum);
+		ifl = net_feed(FEED_JOB, netid, Jobnum, Job_seg.dptr->js_viewport);
 	else
 		ifl = fopen(mkspid(SPNAM, Jobnum), "r");
 
@@ -323,7 +305,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 1);
+	versionprint(argv, "$Revision: 1.1 $", 1);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
