@@ -65,48 +65,20 @@
 #include "cgifndjb.h"
 #include "shutilmsg.h"
 #include "cgiutil.h"
+#include "optflags.h"
 
 #ifndef	_NFILE
 #define	_NFILE	64
 #endif
 
-char	*exitcodename,
-	*signalname;
-
-#ifdef	SHAREDLIBS
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char	*Args[1];
-#endif
-
-FILE	*Cfile;
-
 #define	IPC_MODE	0600
 
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
+extern	int	Ctrl_chan;
 
 ULONG	Saveseq;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-char	*Restru,
-	*Restrg;
-
-char	*jobqueue;		/* Dummy one to read file reqd by rjobfile */
-
 int	exit_code;
 
-char	*Args[1];
-
-BtuserRef	mypriv;
-long		mymtype;
-
 extern int  extractvar(const char **, struct vdescr *);
 
 void  nomem(const char *fl, const int ln)
@@ -860,7 +832,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
