@@ -56,41 +56,10 @@
 
 #define	SYNCMAX		5	/* Before we give up */
 
-FILE	*Cfile;
-
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-
-uid_t	Realuid,
-	Effuid,
-	Daemuid;
-
-gid_t	Realgid,
-	Effgid;
-
-BtuserRef	mypriv;
-
-long		mymtype;
-
-/* The following are just to resolve names used in library routines
-   which we steal.  */
-
-char	*Restru,
-	*Restrg,
-	*jobqueue,
-	*Args[1];
+extern	int	Ctrl_chan;
 
 Btvar	newvar;
 
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*exitcodename, *signalname;
-struct	jshm_info	Job_seg;
-#endif
-
 /* For when we run out of memory.....  */
 
 void  nomem(const char *fl, const int ln)
@@ -380,7 +349,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
