@@ -76,13 +76,10 @@ static	char	*tmpfl;
 unsigned		pend_njobs, pend_max;
 struct	pend_job	*pend_list;
 
-extern	BtuserRef	mypriv;
-
-HelpaltRef	days_abbrev, daynames_full, monnames, repunit, ifnposses;
+HelpaltRef	daynames_full, monnames;
 #ifdef HAVE_XM_SPINB_H
 XmStringTable	timezerof, stdaynames, stmonnames;
 #endif
-char	*exitcodename, *signalname;
 
 int	longest_day,
 	longest_mon;
@@ -783,7 +780,6 @@ void  cb_submit(Widget w, int notused)
 	static	jobno_t		jn;
 	Shipc			Oreq;
 	Repmess			rr;
-	extern	long		mymtype;
 
 	if  ((indx = getselectedjob(1)) < 0)
 		return;
