@@ -17,8 +17,8 @@
 
 #include "config.h"
 
-static	char	rcsid1[] = "@(#) $Id: xmbtq.c,v 1.1.1.1 2009/02/18 06:51:32 toadwarble Exp $";		/* We use these in the about message */
-static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
+static	char	rcsid1[] = "@(#) $Id: xmbtq.c,v 1.1 2009/02/18 06:51:32 toadwarble Exp $";		/* We use these in the about message */
+static	char	rcsid2[] = "@(#) $Revision: 1.1 $";
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -89,37 +89,14 @@ void  allocate_colours();
 #endif
 
 char	*spdir,
-	*Curr_pwd,
-	*jobqueue;
+	*Curr_pwd;
 
-#ifdef	SHAREDLIBS
-char	*Args[1];
-#else
-ULONG	Dispflags;
-#endif
-
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-gid_t	Realgid,
-	Effgid;
-
-FILE	*Cfile;
 char	Confvarname[] = "XMBTQCONF";
 
-int	Ctrl_chan = -1;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-
 int	poll_time;
 
 Shipc		Oreq;
-long		mymtype;
-BtuserRef	mypriv;
-
-char	*Restru, *Restrg;
+extern	long	mymtype;
 
 /* X Stuff */
 
@@ -1025,7 +1002,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
