@@ -16,8 +16,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "config.h"
-static	char	rcsid1[] = "@(#) $Id: xmbtuser.c,v 1.1.1.1 2009/02/18 06:51:32 toadwarble Exp $";		/* We use these in the about message */
-static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
+static	char	rcsid1[] = "@(#) $Id: xmbtuser.c,v 1.1 2009/02/18 06:51:32 toadwarble Exp $";		/* We use these in the about message */
+static	char	rcsid2[] = "@(#) $Revision: 1.1 $";
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -63,33 +63,8 @@ static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
 
 static	char	Filename[] = __FILE__;
 
-FILE	*Cfile;
-
 char	*Curr_pwd;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-gid_t	Realgid,
-	Effgid;
-
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-#include "timecon.h"
-#include "btconst.h"
-#include "bjparam.h"
-#include "btjob.h"
-#include "q_shm.h"
-int		Ctrl_chan;
-long		mymtype;
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*Args[1], *exitcodename, *signalname;
-BtuserRef	mypriv;
-struct	jshm_info	Job_seg;
-char		*jobqueue, *Restru, *Restrg;
-#endif
-
 unsigned	loadstep;
 
 int	hchanges,	/* Had changes to default */
@@ -677,9 +652,8 @@ MAINFN_TYPE  main(int argc, char **argv)
 #if	defined(NHONSUID) || defined(DEBUG)
 	int_ugid_t	chk_uid;
 #endif
-	BtuserRef	mypriv;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
