@@ -54,36 +54,10 @@
 static	char	Filename[] = __FILE__;
 
 char	*Curr_pwd;
-uid_t	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-FILE	*Cfile;
 char	Confvarname[] = "FILEMONCONF";
 
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-#include "bjparam.h"
-#include "cmdint.h"
-#include "btconst.h"
-#include "btmode.h"
-#include "btvar.h"
-#include "btuser.h"
-#include "timecon.h"
-#include "btjob.h"
-#include "q_shm.h"
-
-int		Ctrl_chan;
-long		mymtype;
 uid_t		Daemuid;
 ULONG		Fileprivs;
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*Args[1], *exitcodename, *signalname;
-BtuserRef	mypriv;
-struct		jshm_info	Job_seg;
-char		*Restru, *Restrg, *jobqueue;
-#endif
 
 enum  wot_mode	wotact = WM_STOP_FOUND;
 enum  wot_form	wotf = WF_APPEARS;
@@ -544,7 +518,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	Dimension	h;
 	vrec_t		vrec;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 	init_mcfile();
 	Realuid = getuid();
 	Realgid = getgid();
