@@ -44,17 +44,8 @@
 #include "cgiutil.h"
 #include "rcgilib.h"
 
-FILE	*Cfile;
-
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-int		xbapi_fd = -1;
-apiBtuser	mypriv;
 int		Nvars;
+
 struct	var_with_slot  *var_sl_list;
 
 void  nomem(const char *fl, const int ln)
@@ -194,7 +185,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	char	**newargs;
 	int_ugid_t	chku;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
